/*
 * Copyright (c) 2021 Contributors to the Eclipse Foundation
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 */

package org.eclipse.lsat.scheduler;

import org.eclipse.lsat.common.qvto.util.AbstractModelTransformer;
import org.eclipse.lsat.common.qvto.util.QvtoTransformationException;
import org.eclipse.lsat.common.scheduler.graph.Task;
import org.eclipse.lsat.common.scheduler.schedule.Schedule;
import org.eclipse.m2m.qvt.oml.BasicModelExtent;

public class StochasticImpactAnalysis<T extends Task>
        extends AbstractModelTransformer<StochasticImpactAnalysisInput<T>, Schedule<T>>
{
    @Override
    protected String getDefaultTransformation() {
        return "/transforms/stochasticImpactAnalysis.qvto";
    }

    @SuppressWarnings("unchecked")
    @Override
    protected Schedule<T> doTransformModel(StochasticImpactAnalysisInput<T> input) throws QvtoTransformationException {
        BasicModelExtent inoutSchedule = new BasicModelExtent();
        inoutSchedule.add(input.getSchedule());

        BasicModelExtent inSetting = new BasicModelExtent();
        inSetting.add(input.getSettings());

        execute(inoutSchedule, inSetting);

        return validateOneAndOnlyOne(Schedule.class, inoutSchedule);
    }
}
